@@ -1,6 +1,7 @@
 from typing import TypedDict, Optional
 
 from akeneo_connector.akeneo_connector import AkeneoConnector
+from akeneo_connector.akeneo_units import format_value
 
 class Value(TypedDict):
      locale: Optional[str]
@@ -147,6 +148,55 @@ class AkeneoProduct:
         # Return None if locale and scope are not found
         return None
     
+    def get_linked_data(self, attribute: str, locale: str | None = None, scope: str | None = None) -> dict | None:
+        """
+        Gets the linked data for the given attribute.
+
+        Args:
+            attribute (str): The attribute to get the linked data for.
+            locale (str): The locale of the value.
+            scope (str): The scope of the value.
+
+        Returns:
+            dict: The linked data of the attribute. None if not found.
+        """
+        # Failsafe
+        if attribute not in self.values:
+            return None
+
+        # Try to find the value with locale and scope
+        for value in self.values[attribute]:
+            if value.get('locale') == locale and value.get('scope') == scope:
+                return value.get('linked_data', None)
+
+        # Return first value if locale is None and scope is None
+        if locale is None and scope is None:
+            return self.values[attribute][0].get('linked_data', None)
+        
+        # Return None if locale and scope are not found
+        return None
+    
+    def get_formatted_value(self, attribute: str, locale: str | None = None, scope: str | None = None) -> str:
+        """
+        Gets the formatted value for the given attribute.
+
+        Args:
+            attribute (str): The attribute to get the value for.
+            locale (str): The locale of the value.
+            scope (str): The scope of the value.
+
+        Returns:
+            str: The value of the attribute. "N/A" if not found.
+        """
+        # Get value
+        value = self.get_value(attribute, locale, scope)
+
+        # Get linked data
+        linked_data = self.get_linked_data(attribute, locale, scope)
+
+        # Return formatted value
+        return format_value(value, locale, linked_data)
+            
     def get_href(self, attribute: str, locale: str | None = None, scope: str | None = None) -> str | None:
         """
         Gets the link for a downloadable attribute.
@@ -215,7 +265,7 @@ class AkeneoProduct:
                 'data': data
             })
 
-    def get(self, identifier: str | None = None):
+    def get(self, identifier: str | None = None, with_attribute_options: bool = False):
         """
         Retrieves the product data.
 
@@ -236,6 +286,14 @@ class AkeneoProduct:
         # Build the URL
         url = self.connector.product_url.format(identifier=identifier)
 
+        # Add query parameters
+        query = ""
+        if with_attribute_options:
+            query += "with_attribute_options=true&"
+
+        if query:
+            url += f"?{query}"
+
         # Get the product
         data = self.connector.get(url)
 
